#!/bin/sh
######################################################################
#
# Tivoli Enterprise Data Warehouse, v 1.1.0
# (C) Copyright IBM Corp. 2002.  All Rights Reserved.
#
# US Government Users Restricted Rights - Use, duplication or
# disclosure restricted by GSA ADP Schedule Contract with
# IBM Corp.
#
#
#######################################################################
#
# Command Line Args:
#       1 = the path and name of the TWH Application config file
#       2 = Application working directory or install base directory
#               $TWH_TOPDIR/apps/ava_code_for_app/vapp_version
#               (look at install tree)
#
# Required Config File:
#       twh_app_install.cfg
#
# Installation Logs (Default names):
#       A log will be generated for this scirpt called
#       <ava>_after.sh.log
#
#
# Required Env Vars:
#       TWH_TOPDIR
#
# Return Codes (Only!):
#       0 = Success
#       255 = Failure
#
# Interpreter Required:
#       NT/2000 = BASH
#       Unix    = SH (Bourne Shell)
#
#
# Message Types:
#       (I) - Informational
#       (W) - Warning
#       (F) - Fatal
#
# Install Steps Required Before this Script Executes:
#        * TWH Core tools components must be successfully installed
#
# Note - Caution needs to be taken for NT paths that have a space.
#        This is a limitation that requires double quoting around all
#        variables that contain a path.  Testing should be done to
#        ensure this script runs with a space in any of the paths 
#        that are used.  For example "c:/program files".
#
######################################################################
#

echo "                ** Pre Script Log **"
echo ""
echo "****************************************"
echo "* Application Pre Script Start point *"
echo "****************************************"

# Set parms
echo "      Parm 1 = $1"; TWH_CONFIG_FILE="$1"; export TWH_CONFIG_FILE
echo "      Parm 2 = $2"; APP_WORK_DIR="$2"; export APP_WORK_DIR
echo ""

# TWH_TOPDIR needs to always be in the environment
if [ -z "$TWH_TOPDIR" ]; then
  echo "      (F) Could not locate Env var TWH_TOPDIR"
  exit 255
fi

# Execute startup driver for afterscript
. "$TWH_TOPDIR"/install/bin/twh_core_startup_after.sh
exec_startup_driver;

#####################################################
######## Add application code below here ONLY #######
#####################################################


set_cod_program_vars()
{

# name of the temporary sql file
tmp_sql_file="cod_tmp_sql.sql"

# string of the temporary sql file
tmp_sql_COD="delete from rpi.query q where q.report_id in (select r.report_id from iwh.starschema i, rpi.datamart d, rpi.relationship rel, rpi.report r where i.name ='COD Daily DB2 Database Star Schema' AND rel.rel_type = 'SchemaToDatamart' AND rel.source_id = i.iwhid AND rel.target_id = d.datamart_id AND r.datamart_id = d.datamart_id);
             delete from rpi.report r where r.datamart_id in (select d.datamart_id from iwh.starschema i, rpi.datamart d, rpi.relationship rel where i.name ='COD Daily DB2 Database Star Schema' AND rel.rel_type = 'SchemaToDatamart' AND rel.source_id = i.iwhid AND rel.target_id = d.datamart_id);
             delete from rpi.datamart d where (d.datamart_id in (select rel.target_id from iwh.starschema i, rpi.relationship rel where i.name ='COD Daily DB2 Database Star Schema' AND rel.rel_type = 'SchemaToDatamart' AND rel.source_id = i.iwhid)) OR d.dm_schema = 'COD';
             delete from rpi.relationship rel where rel.rel_type = 'SchemaToResourceBundle' AND rel.source_id in (select i.iwhid from iwh.starschema i where i.name ='COD Daily DB2 Database Star Schema');
             delete from rpi.relationship rel where rel.rel_type = 'ReportToStarSchema' AND rel.target_id in (select i.iwhid from iwh.starschema i where i.name ='COD Daily DB2 Database Star Schema');
             delete from rpi.relationship rel where rel.rel_type = 'SchemaToDatamart' AND rel.source_id in (select i.iwhid from iwh.starschema i where i.name ='COD Daily DB2 Database Star Schema');"

TRUE=1
FALSE=0

return 0;
}


delete_cod_reports()
{
echo "==> Deleting the old COD Reports..."

  # Test a connection
  echo "      (I) Testing the DB connection"
  err_txt=`$DB2EXEC_LOG connect to "$TWH_CTRL_DB" user "$COPT_CTRL_DB2USER" using "$COPT_CTRL_DB2PASS" 2>&1 `
  if [ $? -ne 0 ]; then
    echo "      (F) Unable to connect to database ($TWH_CTRL_DB)."
    echo "          Error is:"
    echo "          $err_txt"
    echo "          Exiting..."
    exit 255
  fi

  # Update it...
  echo "      (I) delete the COD Reports"
  echo "$tmp_sql_COD" > "$TMPDIR/$tmp_sql_file"
  gr_build_exec_script "$TWH_CTRL_DB" "$TMPDIR" "$tmp_sql_file" $COPT_CTRL_TYPE $CONN_TYPE_CONNECT;
  gr_exec_sql_script "$TWH_CTRL_DB" $TRUE;
  rm -f "$TMPDIR/$tmp_sql_file"

  echo "      (I) Done deleting the COD Reports"

return 0;
}


################
# Main section #
################
echo "==> Processing main WPack routines"
echo ""

# Call your routines
set_cod_program_vars;
delete_cod_reports;


echo ""
echo "      (I) Done processing main WPack routines"
#####################################
## Stop adding application code #####
#####################################
exec_core_after;		# DO NOT MOVE OR REMOVE!


echo ""
echo "==> Completed executing application pre script"
exit 0
